package jp.ikedam.jenkins.plugins.constant_parameter;

import hudson.Extension;
import hudson.DescriptorExtensionList;
import hudson.model.Descriptor;
import hudson.model.ParameterValue;
import hudson.model.StringParameterDefinition;

import org.kohsuke.stapler.DataBoundConstructor;
import org.kohsuke.stapler.StaplerRequest;
import net.sf.json.JSONObject;

/**
 * 定数を指定できるビルドパラメータ
 * 変数を使わないとうまく設定できない項目の対応に使用する。
 */
public class ConstantParameterDefinition extends StringParameterDefinition
{
    private static final long serialVersionUID = 1L;
    
    /**
     * ビューでの接続に使用される情報の定義。
     * resource 以下の、クラス名に対応するパスの以下のファイルを使用する。
     *   config.jelly...ジョブの設定時に使用する
     *   index.jelly...ビルド時のパラメータの指定時に使用する。
     * TODO: パラメータチェックを行う。
     */
    @Extension
    public static class DescriptorImpl extends ParameterDescriptor
    {
        /**
         * ジョブ設定でビルドパラメータの追加時に表示される項目名
         */
        @Override
        public String getDisplayName()
        {
            return Messages._ConstantParameterDefinition_DisplayName().toString();
        }
    }
    
    /**
     * Jenkinsが画面入力からこのオブジェクトを作成するときに使用するコンストラクタ。
     * (設定から復元される時にはコンストラクタを使わずオブジェクトが直接復元される)
     */
    @DataBoundConstructor
    public ConstantParameterDefinition(String name, String defaultValue, String description)
    {
        super(name, defaultValue, description);
    }
    
    /**
     * ビルド時に使用するパラメータをユーザの入力から決定する。
     */
    @Override
    public ParameterValue createValue(StaplerRequest request, JSONObject jo)
    {
        return getDefaultParameterValue();
    }
    
    /**
     * ビルド時に使用するパラメータをユーザの入力から決定する。
     */
    @Override
    public ParameterValue createValue(String value)
    {
        return getDefaultParameterValue();
    }
}
